@@ -1,6 +1,9 @@
 from scrapy.utils.misc import load_object
 from scrapy.utils.serialize import ScrapyJSONEncoder
 from twisted.internet.threads import deferToThread
+import logging
+
+logger = logging.getLogger(__name__)
 
 from . import connection
 
@@ -19,18 +22,13 @@ class RabbitmqPipeline(object):
         if hasattr(crawler.spider, 'items_key'):
             item_key = crawler.spider.items_key
         else:
-            item_key = 'items_{spider_name}'.format(
-                spider_name=crawler.spider.name)
-        return cls(item_key=item_key,
-                   connection_url=crawler.settings.get(
-                       'RABBITMQ_CONNECTION_PARAMETERS'))
+            item_key = 'items_{spider_name}'.format(spider_name=crawler.spider.name)
+        return cls(item_key=item_key, connection_url=crawler.settings.get('RABBITMQ_CONNECTION_PARAMETERS'))
 
     def process_item(self, item, spider):
         data = self.serialize(item)
 
-        self.channel.basic_publish(exchange='',
-                                   routing_key=self.item_key,
-                                   body=data)
+        self.channel.basic_publish(exchange='', routing_key=self.item_key, body=data)
         return item
 
     def close(self):
