@@ -3,7 +3,7 @@ import sys
 import time
 import pika
 import logging
-from scrapy.utils.reqser import request_to_dict
+from scrapy.utils.request import request_to_dict
 # module packages
 from . import connection
 from . import picklecompat
@@ -117,7 +117,8 @@ class RabbitMQQueue(IQueue):
             try:
                 self.server.close()
             except:
-                pass
+                logger.error('server close error!!!')
+                # pass
 
         self.server = connection.connect(self.connection_url)
 
